summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart/keximacrodesignview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/kexipart/keximacrodesignview.h')
-rw-r--r--kexi/plugins/macros/kexipart/keximacrodesignview.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacrodesignview.h b/kexi/plugins/macros/kexipart/keximacrodesignview.h
index c3eca2d2..e982f1bd 100644
--- a/kexi/plugins/macros/kexipart/keximacrodesignview.h
+++ b/kexi/plugins/macros/kexipart/keximacrodesignview.h
@@ -41,6 +41,7 @@ class KexiTableItem;
class KexiMacroDesignView : public KexiMacroView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -48,10 +49,10 @@ class KexiMacroDesignView : public KexiMacroView
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroDesignView(KexiMainWindow *mainwin, QWidget *parent, ::KoMacro::Macro* const macro);
+ KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro);
/**
* Destructor.
@@ -75,7 +76,7 @@ class KexiMacroDesignView : public KexiMacroView
* Called before a cell changed in the internaly used
* \a KexiTableView .
*/
- void beforeCellChanged(KexiTableItem*, int, QVariant&, KexiDB::ResultInfo*);
+ void beforeCellChanged(KexiTableItem*, int, TQVariant&, KexiDB::ResultInfo*);
/**
* Called if the passed \p item got updated.
@@ -90,7 +91,7 @@ class KexiMacroDesignView : public KexiMacroView
/**
* Called if a row got inserted.
*/
- void rowInserted(KexiTableItem* item, uint row, bool repaint);
+ void rowInserted(KexiTableItem* item, uint row, bool tqrepaint);
/**
* Called if a property in the \a KoProperty got changed.
@@ -117,7 +118,7 @@ class KexiMacroDesignView : public KexiMacroView
* Update the \a KoProperty::Set set with the passed \a KoMacro::MacroItem
* \p item and the variablename \p variablename .
*/
- bool updateSet(KoProperty::Set* set, KSharedPtr<KoMacro::MacroItem> item, const QString& variablename);
+ bool updateSet(KoProperty::Set* set, KSharedPtr<KoMacro::MacroItem> item, const TQString& variablename);
/**
* Update the properties of the \a KoProperty::Set \p set at
@@ -48,10 +49,10 @@ class KexiMacroDesignView : public KexiMacroView
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param parent The parent widget this widget should be displayed in.
+ * \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/